@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -33,6 +33,9 @@
 
 #include <gst/video/video.h>
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
@@ -47,6 +50,8 @@
 #include "gst-enum-types.h"
 #include "gstmarshal.h"
 
+
+
 #define HIDE_WINDOW_CURSOR_TIMEOUT 3.0f
 
 #define PAROLE_GST_GET_PRIVATE(o) \
@@ -560,6 +565,28 @@ parole_gst_load_logo (ParoleGst *gst)
     g_free (path);
 }
 
+static void
+parole_gst_query_capabilities (ParoleGst *gst)
+{
+    GstQuery *query;
+    gboolean seekable;
+    
+    query = gst_query_new_seeking (GST_FORMAT_TIME);
+    
+    if ( gst_element_query (gst->priv->playbin, query) )
+    {
+	gst_query_parse_seeking (query,
+				 NULL,
+				 &seekable,
+				 NULL,
+				 NULL);
+	g_object_set (G_OBJECT (gst->priv->stream),
+	          "seekable", seekable,
+		  NULL);
+    }
+    gst_query_unref (query);
+}
+
 static gboolean
 parole_gst_tick_timeout (gpointer data)
 {
@@ -569,11 +596,16 @@ parole_gst_tick_timeout (gpointer data)
     GstFormat format = GST_FORMAT_TIME;
     gint64 value;
     gboolean video;
+    gboolean seekable;
+    gint64 duration;
+    
     
     gst = PAROLE_GST (data);
     
     g_object_get (G_OBJECT (gst->priv->stream),
 		  "has-video", &video,
+		  "seekable", &seekable,
+		  "duration", &duration,
 		  NULL);
     
     gst_element_query_position (gst->priv->playbin, &format, &pos);
@@ -583,6 +615,11 @@ parole_gst_tick_timeout (gpointer data)
 
     if ( gst->priv->state == GST_STATE_PLAYING )
     {
+	if (duration != 0 && seekable == FALSE)
+	{
+	    parole_gst_query_capabilities (gst);
+	}
+	    
 	value = pos / GST_SECOND;
 
 	if ( G_LIKELY (value > 0) )
@@ -614,28 +651,6 @@ parole_gst_tick (ParoleGst *gst)
     }    
 }
 
-static void
-parole_gst_query_capabilities (ParoleGst *gst)
-{
-    GstQuery *query;
-    gboolean seekable;
-    
-    query = gst_query_new_seeking (GST_FORMAT_TIME);
-    
-    if ( gst_element_query (gst->priv->playbin, query) )
-    {
-	gst_query_parse_seeking (query,
-				 NULL,
-				 &seekable,
-				 NULL,
-				 NULL);
-	g_object_set (G_OBJECT (gst->priv->stream),
-	          "seekable", seekable,
-		  NULL);
-    }
-    gst_query_unref (query);
-}
-
 static void
 parole_gst_query_duration (ParoleGst *gst)
 {
@@ -655,7 +670,7 @@ parole_gst_query_duration (ParoleGst *gst)
 	duration =  absolute_duration / GST_SECOND;
 	live = ( absolute_duration == 0 );
 	
-	TRACE ("Duration %lld is_live=%d", duration, live);
+	TRACE ("Duration %" G_GINT64_FORMAT "is_live=%d", duration, live);
 	
 	g_object_set (G_OBJECT (gst->priv->stream),
 		      "absolute-duration", absolute_duration,
@@ -930,12 +945,24 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 	    break;
 	}
 	case GST_STATE_PAUSED:
-	    if ( old == GST_STATE_READY )
+	{
+	    if ( pending == GST_STATE_PLAYING )
 	    {
-		parole_gst_query_duration (gst);
-		parole_gst_query_capabilities (gst);
-		parole_gst_query_info (gst);
+		ParoleMediaType media_type;
+		
+		g_object_get (G_OBJECT (gst->priv->stream),
+			      "media-type", &media_type,
+			      NULL);
+		
+		if ( (media_type == PAROLE_MEDIA_TYPE_LOCAL_FILE && old == GST_STATE_READY) ||
+		      media_type != PAROLE_MEDIA_TYPE_LOCAL_FILE )
+		{
+		    parole_gst_query_duration (gst);
+		    parole_gst_query_capabilities (gst);
+		    parole_gst_query_info (gst);
+		}
 	    }
+
 	    if ( gst->priv->target == GST_STATE_PLAYING )
 	    {
 		if ( gst->priv->update_color_balance )
@@ -946,13 +973,15 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_STATE], 0, 
 			   gst->priv->stream, PAROLE_MEDIA_STATE_PAUSED);
 	    break;
+	}
 	case GST_STATE_READY:
+	{
 	    gst->priv->buffering = FALSE;
 	    gst->priv->media_state = PAROLE_MEDIA_STATE_STOPPED;
 	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_STATE], 0, 
 			   gst->priv->stream, PAROLE_MEDIA_STATE_STOPPED);
 
-	    if ( gst->priv->target == GST_STATE_PLAYING && pending != GST_STATE_PLAYING)
+	    if ( gst->priv->target == GST_STATE_PLAYING && pending < GST_STATE_PAUSED)
 	    {
 		parole_gst_play_file_internal (gst);
 	    }
@@ -966,12 +995,15 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    }
 	    break;
+	}
 	case GST_STATE_NULL:
+	{
 	    gst->priv->buffering = FALSE;
 	    gst->priv->media_state = PAROLE_MEDIA_STATE_STOPPED;
 	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_STATE], 0, 
 			   gst->priv->stream, PAROLE_MEDIA_STATE_STOPPED);
 	    break;
+	}
 	default:
 	    break;
     }
@@ -1454,6 +1486,7 @@ parole_gst_change_dvd_chapter (ParoleGst *gst, gint level)
 {
     GstFormat format;
 
+    // FIXME: Do we really need to get the nick each time?
     format = gst_format_get_by_nick ("chapter");
     
     parole_gst_seek_by_format (gst, format, level);
@@ -2151,7 +2184,7 @@ gint parole_gst_get_current_cdda_track (ParoleGst *gst)
     
     if ( gst_element_query_position (gst->priv->playbin, &format, &pos) )
     {
-	TRACE ("Pos %lld", pos);
+	TRACE ("Pos %" G_GINT64_FORMAT, pos);
 	ret_val = (gint) pos;
     }
 	
