@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -69,8 +69,6 @@ parole_file_finalize (GObject *object)
     file = PAROLE_FILE (object);
     priv = PAROLE_FILE_GET_PRIVATE (file);
     
-    g_debug ("File object finalized %s", priv->display_name);
-    
     if ( priv->filename )
 	g_free (priv->filename);
 
@@ -312,6 +310,8 @@ parole_file_init (ParoleFile *file)
  * 
  * 
  * Returns: A new #ParoleFile object.
+ * 
+ * Since: 0.2
  **/
 ParoleFile *
 parole_file_new (const gchar *filename)
@@ -321,6 +321,16 @@ parole_file_new (const gchar *filename)
     return file;
 }
 
+/**
+ * parole_file_new_with_display_name:
+ * @filename: filename.
+ * 
+ * 
+ * 
+ * Returns: A new #ParoleFile object.
+ * 
+ * Since: 0.2
+ **/
 ParoleFile *
 parole_file_new_with_display_name (const gchar *filename, const gchar *display_name)
 {
@@ -338,6 +348,8 @@ parole_file_new_with_display_name (const gchar *filename, const gchar *display_n
  *  
  * 
  * Returns: A string containing the file name.
+ * 
+ * Since: 0.2
  **/
 const gchar *
 parole_file_get_file_name (const ParoleFile *file)
@@ -353,6 +365,8 @@ parole_file_get_file_name (const ParoleFile *file)
  *  
  * 
  * Returns: A string containing the display name.
+ * 
+ * Since: 0.2
  **/
 const gchar *
 parole_file_get_display_name (const ParoleFile *file)
@@ -368,6 +382,8 @@ parole_file_get_display_name (const ParoleFile *file)
  *  
  * 
  * Returns: A string containing the file uri.
+ * 
+ * Since: 0.2
  **/
 const gchar *
 parole_file_get_uri (const ParoleFile *file)
@@ -383,6 +399,8 @@ parole_file_get_uri (const ParoleFile *file)
  *  
  * 
  * Returns: A string containing the content type of the file.
+ * 
+ * Since: 0.2
  **/
 const gchar *
 parole_file_get_content_type (const ParoleFile *file) 
