@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -150,8 +150,16 @@ static void parole_stream_set_property (GObject *object,
 	    PAROLE_STREAM_DUP_GVALUE_STRING (PAROLE_STREAM_GET_PRIVATE (stream)->subtitles, value);
 	    break;
 	case PROP_LIVE:
-	    PAROLE_STREAM_GET_PRIVATE (stream)->live = g_value_get_boolean (value);
+	{
+	    ParoleStreamPrivate *priv;
+	    gboolean maybe_remote;
+	    
+	    priv = PAROLE_STREAM_GET_PRIVATE (stream);
+	    maybe_remote = priv->media_type == PAROLE_MEDIA_TYPE_REMOTE ||
+	                   priv->media_type == PAROLE_MEDIA_TYPE_UNKNOWN;
+	    priv->live = g_value_get_boolean (value) && maybe_remote;
 	    break;
+	}
 	case PROP_MEDIA_TYPE:
 	    PAROLE_STREAM_GET_PRIVATE (stream)->media_type = g_value_get_enum (value);
 	    break;
@@ -444,7 +452,7 @@ parole_stream_class_init (ParoleStreamClass *klass)
      * Since: 0.2 
      **/
     g_object_class_install_property (object_class,
-				     PROP_SEEKABLE,
+				     PROP_TAG_AVAILABLE,
 				     g_param_spec_boolean ("tag-available",
 							   "Tag available",
 							   "Tag available",
