@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -31,8 +31,9 @@
 #include <libnotify/notify.h>
 #endif
 
-#include <libxfcegui4/libxfcegui4.h>
+
 #include <libxfce4util/libxfce4util.h>
+#include <libxfcegui4/libxfcegui4.h>
 
 #include "tray-provider.h"
 
@@ -42,6 +43,9 @@ static void   tray_provider_iface_init 	   (ParoleProviderPluginIface *iface);
 static void   tray_provider_finalize       (GObject 	              *object);
 
 
+extern GdkPixbuf      *parole_icon_load    (const gchar *icon_name,  gint size);
+
+
 struct _TrayProviderClass
 {
     GObjectClass parent_class;
@@ -194,6 +198,23 @@ notification_closed_cb (NotifyNotification *n, TrayProvider *tray)
     tray->n = NULL;
 }
 
+static void
+close_notification (TrayProvider *tray)
+{
+    if ( tray->n )
+    {
+	GError *error = NULL;
+	notify_notification_close (tray->n, &error);
+	if ( error )
+	{
+	    g_warning ("Failed to close notification : %s", error->message);
+	    g_error_free (error);
+	}
+	g_object_unref (tray->n);
+	tray->n = NULL;
+    }
+}
+
 static void
 notify_playing (TrayProvider *tray, const ParoleStream *stream)
 {
@@ -260,13 +281,25 @@ notify_playing (TrayProvider *tray, const ParoleStream *stream)
     }
     
     message = g_strdup_printf ("%s %s %s %s", _("<b>Playing:</b>"), title, _("<b>Duration:</b>"), timestring);
-    
+
+#ifdef NOTIFY_CHECK_VERSION
+#if NOTIFY_CHECK_VERSION (0, 7, 0)    
+    tray->n = notify_notification_new (title, message, NULL);
+#else
     tray->n = notify_notification_new (title, message, NULL, NULL);
+#endif
+#else
+    tray->n = notify_notification_new (title, message, NULL, NULL);
+#endif
     g_free (title);
     g_free (message);
     
+#ifdef NOTIFY_CHECK_VERSION
+#if !NOTIFY_CHECK_VERSION (0, 7, 0)
     notify_notification_attach_to_status_icon (tray->n, tray->tray);
-    pix = xfce_themed_icon_load (has_video ? "video" : "audio-x-generic", 48);
+#endif
+#endif
+    pix = parole_icon_load (has_video ? "video" : "audio-x-generic", 48);
     if ( pix )
     {
 	notify_notification_set_icon_from_pixbuf (tray->n, pix);
@@ -286,10 +319,6 @@ notify_playing (TrayProvider *tray, const ParoleStream *stream)
 static void
 state_changed_cb (ParoleProviderPlayer *player, const ParoleStream *stream, ParoleState state, TrayProvider *tray)
 {
-#ifdef HAVE_LIBNOTIFY
-    gboolean tag;
-#endif
-
     tray->state = state;
     
     if ( tray->menu )
@@ -303,47 +332,17 @@ state_changed_cb (ParoleProviderPlayer *player, const ParoleStream *stream, Paro
 
     if ( state == PAROLE_STATE_PLAYING )
     {
-	g_object_get (G_OBJECT (stream),
-		      "tag-available", &tag,
-		      NULL);
-
-	if ( tag )
-	    notify_playing (tray, stream);
+	notify_playing (tray, stream);
     }
     else if ( state <= PAROLE_STATE_PAUSED )
     {
-	if ( tray->n )
-	{
-	    GError *error = NULL;
-	    notify_notification_close (tray->n, &error);
-	    if ( error )
-	    {
-		g_warning ("Failed to close notification : %s", error->message);
-		g_error_free (error);
-	    }
-	    g_object_unref (tray->n);
-	    tray->n = NULL;
-	}
+	close_notification (tray);
 	if ( state < PAROLE_STATE_PAUSED )
 	    tray->notify = TRUE;
     }
 #endif
 }
 
-static void
-tag_message_cb (ParoleProviderPlayer *player, const ParoleStream *stream, TrayProvider *tray)
-{
-#ifdef HAVE_LIBNOTIFY
-    ParoleState state;
-    
-    state = parole_provider_player_get_state (player);
-    
-    if (state == PAROLE_STATE_PLAYING )
-	notify_playing (tray, stream);
-    
-#endif
-}
-
 static gboolean
 read_entry_bool (const gchar *entry, gboolean fallback)
 {
@@ -514,16 +513,24 @@ delete_event_cb (GtkWidget *widget, GdkEvent *ev, TrayProvider *tray)
     switch ( gtk_dialog_run (GTK_DIALOG (dialog)) )
     {
 	case GTK_RESPONSE_OK:
-	    gtk_widget_hide_on_delete (widget);
-	    break;
+	    {
+		gtk_widget_hide_on_delete (widget);
+		confirmed = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+		if ( confirmed )
+		    write_entry_bool ("MINIMIZE_TO_TRAY", TRUE);
+		break;
+	    }
 	case GTK_RESPONSE_CLOSE:
-	    ret_val = FALSE;
+	    {
+		confirmed = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+		if ( confirmed )
+		    write_entry_bool ("MINIMIZE_TO_TRAY", FALSE);
+		ret_val = FALSE;
+	    }
 	    break;
 	case GTK_RESPONSE_CANCEL:
-	    ret_val = TRUE;
 	    break;
 	default:
-	    ret_val = TRUE;
 	    break;
     }
     
@@ -565,7 +572,7 @@ tray_provider_set_player (ParoleProviderPlugin *plugin, ParoleProviderPlayer *pl
     tray->notify = TRUE;
 #endif
     
-    pix = xfce_themed_icon_load ("parole", 48);
+    pix = parole_icon_load ("parole", 48);
     
     if ( pix )
     {
@@ -584,10 +591,6 @@ tray_provider_set_player (ParoleProviderPlugin *plugin, ParoleProviderPlayer *pl
 				  
     g_signal_connect (player, "state_changed", 
 		      G_CALLBACK (state_changed_cb), tray);
-		      
-    g_signal_connect (player, "tag-message",
-		      G_CALLBACK (tag_message_cb), tray);
-
 }
 
 static void
@@ -626,6 +629,10 @@ static void tray_provider_finalize (GObject *object)
     
     if ( GTK_IS_WIDGET (tray->window) && g_signal_handler_is_connected (tray->window, tray->sig) )
 	g_signal_handler_disconnect (tray->window, tray->sig);
+
+#ifdef HAVE_LIBNOTIFY 
+    close_notification (tray);
+#endif
  
     g_object_unref (G_OBJECT (tray->tray));
     
