@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2008-2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -72,14 +72,26 @@ parole_send_play_disc (const gchar *uri, const gchar *device)
 {
     DBusGProxy *proxy;
     GError *error = NULL;
+    gchar *uri_local;
+    
+    if ( uri )
+    {
+	uri_local = g_strdup (uri);
+    }
+    else
+    {
+	uri_local = parole_get_uri_from_unix_device (device);
+    }
     
     proxy = parole_get_proxy (PAROLE_DBUS_PATH, PAROLE_DBUS_INTERFACE);
     
     dbus_g_proxy_call (proxy, "PlayDisc", &error,
-		       G_TYPE_STRING, uri,
+		       G_TYPE_STRING, uri_local,
 		       G_TYPE_STRING, device,
 		       G_TYPE_INVALID,
 		       G_TYPE_INVALID);
+    
+    g_free (uri_local);
 		       
     if ( error )
     {
@@ -205,6 +217,7 @@ int main (int argc, char **argv)
     gboolean lower_volume = FALSE;
     gboolean mute = FALSE;
     gboolean no_plugins = FALSE;
+    gboolean fullscreen = FALSE;
     gchar    *client_id = NULL;
     
     GOptionEntry option_entries[] = 
@@ -222,6 +235,7 @@ int main (int argc, char **argv)
 	{ "lower-volume", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &lower_volume, N_("Lower volume"), NULL },
 	{ "mute", 'm', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &mute, N_("Mute volume"), NULL },
 	{ "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &version, N_("Version information"), NULL },
+	{ "fullscreen", 'F', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &fullscreen, N_("Start in fullscreen mode"), NULL },
 	{ "xv", '\0', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_CALLBACK, (GOptionArgFunc) xv_option_given, N_("Enabled/Disable XV support"), NULL},
 	{ "sm-client-id", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &client_id, NULL, NULL },
 	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, N_("Media to play"), NULL},
@@ -265,6 +279,8 @@ int main (int argc, char **argv)
 	
 	if ( filenames && filenames[0] != NULL )
 	    parole_send (filenames, device);
+	else if (device != NULL)
+	    parole_send_play_disc (NULL, device);
 	
 	if ( play )
 	    parole_send_message ("Play");
@@ -304,6 +320,9 @@ int main (int argc, char **argv)
 	    
 	parole_session_real_init (session);
 	player = parole_player_new ();
+	
+	if (fullscreen)
+	    parole_player_full_screen (player, TRUE);
 
 	if ( filenames && filenames[0] != NULL )
 	{
@@ -318,6 +337,10 @@ int main (int argc, char **argv)
 		parole_media_list_add_files (list, filenames);
 	    }
 	}
+	else if ( device != NULL )
+	{
+	    parole_player_play_uri_disc (player, NULL, device);
+	}
 	
 	if ( xfce_posix_signal_handler_init (&error)) 
 	{
