@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -26,6 +26,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
@@ -46,11 +50,29 @@ void  parole_about (void)
     } 	
     translators[] = 
     {
-	{"", "", "",},
+	{"astur", "malditoastur@gmail.com", "ast",},
+	{"Carles Muñoz Gorriz", "carlesmu@internautas.org", "ca.po",},
+	{"Per Kongstad", "p_kongstad@op.pl", "da.po",},
+	{"Christoph Wickert", "cwickert@fedoraproject.org", "de.po",},
+	{"elega", "elega@elega.com.ar","es",},
+	{"Piarres Beobide", "pi+debian@beobide.net", "eu",},
+	{"Douart Patrick", "patrick.2@laposte.net", "fr",},
+	{"Leandro Regueiro", "leandro.regueiro@gmail.com", "gl",},
+	{"Andhika Padmawan", "andhika.padmawan@gmail.com", "id",},
+	{"Masato Hashimoto", "cabezon.hashimoto@gmail.com", "ja",},
+	{"Rihards Prieditis", "rprieditis@gmail.com", "lv",},
+	{"Mario Blättermann", "mariobl@gnome.org", "nl",},
+	{"Sérgio Marques", "smarquespt@gmail.com", "pt",},
+	{"Vlad Vasilev", "lortwer@gmail.com", "ru",},
+	{"Robert Hartl", "hartl.robert@gmail.com", "sk",},
+	{"Samed Beyribey", "ras0ir@eventualis.org", "tr",},
+	{"Motsyo Gennadi", "drool@altlinux.ru", "uk",},
+	{"Hunt Xu", "huntxu@live.cn", "zh_CN",},
+	
     };
 
     info = xfce_about_info_new ("Parole", VERSION, _("Parole Media Player"),
-                                XFCE_COPYRIGHT_TEXT ("2009", "Ali Abdallah"), 
+                                XFCE_COPYRIGHT_TEXT ("2009-2011", "Ali Abdallah"), 
 				XFCE_LICENSE_GPL);
 
     xfce_about_info_set_homepage (info, "http://goodies.xfce.org/projects/applications/parole");
