@@ -1,5 +1,5 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -28,6 +28,10 @@
 
 #include <glib.h>
 
+
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
 #include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
@@ -367,13 +371,13 @@ parole_plugins_manager_get_plugin_info (const gchar *desktop_file)
 	goto out;
     }
     
-    info->name = g_key_file_get_string (file, "Parole Plugin", "Name", NULL);
+    info->name = g_key_file_get_locale_string (file, "Parole Plugin", "Name", NULL, NULL);
     
     if ( !info->name )
 	info->name = g_strdup (_("Unknown"));
     
     
-    info->desc = g_key_file_get_string (file, "Parole Plugin", "Description", NULL);
+    info->desc = g_key_file_get_locale_string (file, "Parole Plugin", "Description", NULL, NULL);
     
     if ( !info->desc )
 	info->desc = g_strdup ("");
